# EllucianEthosPythonClient
Python Client Library for interfacing with Ellucian Ethos

In development - not ready for production use

## Aims

This library aims to provied:

 - Wrapper class to handle Ethos authorizations
 - Wrapper classes that call Ellucian API's to fetch resources
 - Common updates on resources
 - Provide mock running mode to allow for testing without calling Ethos
 
## Usage examples

For a quick start usage example using the python REPL follow the [Quickstart](./docs/QUICKSTART.md) guide.



## Background

I started putting this python library after an Ethos user group meeting. There are a number of other Ellucian customers
all writing clients and I wanted to take the oppertunity of digging out exmaples I had written for myself and my team
and sharing them with the community.
  
 

